@@ -118,37 +118,48 @@ class CompositionalUnit(TemporalUnit):
                  beat     : Union[None, Fraction, int, float, str] = None,
                  bpm      : Union[None, int, float]                = None,
                  offset   : float                                  = 0,
+                 inst     : Union[Instrument, None]                = None,
+                 mfields  : Union[dict, list, None]                = None,
                  pfields  : Union[dict, list, None]                = None):
         
         super().__init__(span, tempus, prolatio, beat, bpm, offset)
         
-        self._pt = self._create_synchronized_parameter_tree(pfields)
+        if mfields is None:
+            mfields = {}
+        if 'group' not in mfields:
+            mfields['group'] = 'default'
+        
+        self._pt = self._create_synchronized_parameter_tree(pfields, inst, mfields)
         
         self._envelopes = {}
         self._next_envelope_id = 0
         self._envelope_offset = offset
     
     @classmethod
-    def from_rt(cls, rt: RhythmTree, beat: Union[None, Fraction, int, float, str] = None, bpm: Union[None, int, float] = None, pfields: Union[dict, list, None] = None):
+    def from_rt(cls, rt: RhythmTree, beat: Union[None, Fraction, int, float, str] = None, bpm: Union[None, int, float] = None, pfields: Union[dict, list, None] = None, mfields: Union[dict, list, None] = None, inst: Union[Instrument, None] = None):
         return cls(span     = rt.span,
                    tempus   = rt.meas,
                    prolatio = rt.subdivisions,
                    beat     = beat,
                    bpm      = bpm,
                    offset   = 0,
-                   pfields  = pfields)
+                   pfields  = pfields,
+                   mfields  = mfields,
+                   inst     = inst)
         
     @classmethod
-    def from_ut(cls, ut: TemporalUnit, pfields: Union[dict, list, None] = None):
+    def from_ut(cls, ut: TemporalUnit, pfields: Union[dict, list, None] = None, mfields: Union[dict, list, None] = None, inst: Union[Instrument, None] = None):
         return cls(span     = ut.span,
                    tempus   = ut.tempus,
                    prolatio = ut.prolationis,
                    beat     = ut.beat,
                    bpm      = ut.bpm,
                    offset   = ut.offset,
-                   pfields  = pfields)
+                   pfields  = pfields,
+                   mfields  = mfields,
+                   inst     = inst)
     
-    def _create_synchronized_parameter_tree(self, pfields: Union[dict, list, None]) -> ParameterTree:
+    def _create_synchronized_parameter_tree(self, pfields: Union[dict, list, None], inst: Union[Instrument, None] = None, mfields: Union[dict, list, None] = None) -> ParameterTree:
         """
         Create a ParameterTree with identical structure to the RhythmTree but blank node data.
         
@@ -156,6 +167,10 @@ class CompositionalUnit(TemporalUnit):
         ----------
         pfields : Union[dict, list, None]
             Parameter fields to initialize
+        inst : Union[Instrument, None], optional
+            Instrument to set on the root node
+        mfields : Union[dict, list, None], optional
+            Meta fields to initialize
             
         Returns
         -------
@@ -171,6 +186,12 @@ class CompositionalUnit(TemporalUnit):
         if pfields is not None:
             self._initialize_parameter_fields(pt, pfields)
         
+        if inst is not None:
+            pt.set_instrument(pt.root, inst)
+        
+        if mfields is not None:
+            self._initialize_meta_fields(pt, mfields)
+        
         return pt
     
     def _initialize_parameter_fields(self, pt: ParameterTree, pfields: Union[dict, list]):
@@ -190,6 +211,23 @@ class CompositionalUnit(TemporalUnit):
             default_values = {field: 0.0 for field in pfields}
             pt.set_pfields(pt.root, **default_values)
 
+    def _initialize_meta_fields(self, pt: ParameterTree, mfields: Union[dict, list]):
+        """
+        Initialize meta fields across all nodes in the parameter tree.
+        
+        Parameters
+        ----------
+        pt : ParameterTree
+            The parameter tree to initialize
+        mfields : Union[dict, list]
+            Meta fields to set
+        """
+        if isinstance(mfields, dict):
+            pt.set_mfields(pt.root, **mfields)
+        elif isinstance(mfields, list):
+            default_values = {field: '' for field in mfields}
+            pt.set_mfields(pt.root, **default_values)
+
     def _validate_non_overlapping_subtrees(self, nodes):
         """Ensure no node is a descendant of another in the list"""
         for i, node1 in enumerate(nodes):
@@ -269,6 +307,18 @@ class CompositionalUnit(TemporalUnit):
         """
         return self._pt.pfields
     
+    @property
+    def mfields(self) -> list:
+        """
+        List of all available meta field names.
+        
+        Returns
+        -------
+        list of str
+            Sorted list of meta field names
+        """
+        return self._pt.mfields
+    
     @property
     def events(self):
         """
@@ -364,6 +414,24 @@ class CompositionalUnit(TemporalUnit):
         
         self._evaluate_envelopes()
 
+    def set_mfields(self, node: Union[int, list], **kwargs) -> None:
+        """
+        Set meta field values for a specific node(s) and their descendants.
+        
+        Meta fields are static metadata that don't support envelope automation.
+        
+        Parameters
+        ----------
+        node : Union[int, list]
+            The node ID(s) to set meta fields for
+        **kwargs
+            Meta field names and values to set
+        """
+        nodes = [node] if not isinstance(node, (list, tuple, set)) else list(node)
+        
+        for n in nodes:
+            self._pt.set_mfields(n, **kwargs)
+
     def apply_envelope(self, level: Union[int, str], range_span: Union[tuple, int, None], envelope: Envelope, pfields: Union[str, list], endpoint: bool = True) -> int:
         """
         Apply envelope to a consecutive span of nodes at a specific level.
@@ -570,7 +638,8 @@ class CompositionalUnit(TemporalUnit):
         Any
             The parameter value or default
         """
-        return self._pt.get(node, key) or default
+        value = self._pt.get(node, key)
+        return value if value is not None else default
     
     def clear_parameters(self, node: int = None) -> None:
         """
@@ -611,8 +680,6 @@ class CompositionalUnit(TemporalUnit):
             self._events = self._evaluate()
         return self._events[idx].parameters
     
-
-    
     def from_subtree(self, node: int) -> 'CompositionalUnit':
         """
         Create a new CompositionalUnit from a subtree of this one.
@@ -652,17 +719,34 @@ class CompositionalUnit(TemporalUnit):
         original_subtree_nodes = [node] + list(self._rt.descendants(node))
         
         # First, copy any instrument assignments that apply to this subtree
-        # Look for the governing instrument node for this subtree
-        governing_instrument_node = self._pt.get_governing_subtree_node(node)
-        if governing_instrument_node is not None and governing_instrument_node in self._pt._node_instruments:
-            # Apply the same instrument to the root of the new subtree
-            instrument = self._pt._node_instruments[governing_instrument_node]
-            new_cu.set_instrument(new_cu._pt.root, instrument)
+        # When copying the full tree (node == root), preserve ALL instruments
+        # When copying a subtree, only preserve the governing instrument
+        if node == self._rt.root:
+            # Full tree copy - preserve ALL instruments with proper node mapping
+            old_to_new_mapping = {}
+            old_nodes = [node] + list(self._rt.descendants(node))
+            new_nodes = list(new_cu._pt.nodes)
+            
+            # Create mapping based on tree structure (breadth-first traversal order)
+            for i, old_node in enumerate(old_nodes):
+                if i < len(new_nodes):
+                    old_to_new_mapping[old_node] = new_nodes[i]
+            
+            # Copy all instruments using the mapping
+            for old_node, instrument in self._pt._node_instruments.items():
+                if old_node in old_to_new_mapping:
+                    new_node = old_to_new_mapping[old_node]
+                    new_cu.set_instrument(new_node, instrument)
+        else:
+            # Subtree copy - only preserve governing instrument (original behavior)
+            governing_instrument_node = self._pt.get_governing_subtree_node(node)
+            if governing_instrument_node is not None and governing_instrument_node in self._pt._node_instruments:
+                instrument = self._pt._node_instruments[governing_instrument_node]
+                new_cu.set_instrument(new_cu._pt.root, instrument)
         
         # Copy parameter data from all nodes in the original subtree to corresponding nodes in the new tree
         # Since RhythmTree.subtree creates a completely new tree structure with renumbered nodes,
         # we need to map the parameter data appropriately
-        original_subtree_nodes = [node] + list(self._rt.descendants(node))
         new_tree_nodes = list(new_cu._pt.nodes)
         
         # Create a mapping based on tree structure position
