@@ -33,16 +33,17 @@ harmonic_trees = systems.harmonic_trees
 
 from .pitch import Pitch, PitchCollection, EquaveCyclicCollection, AddressedPitchCollection
 from .scales import Scale
-from .chords import Chord
+from .chords import Chord, Sonority, ChordSequence
 from .motives import Motive
 from .systems.combination_product_sets import CombinationProductSet, Hexany, Dekany, Pentadekany, Eikosany
 from .systems.harmonic_trees import HarmonicTree
 from .systems.harmonic_trees.spectrum import Spectrum
+from .systems.tone_lattices import ToneLattice
 from .scales.scale import AddressedScale
-from .chords.chord import AddressedChord
+from .chords.chord import AddressedChord, AddressedSonority
 
 from .utils.intervals import ratio_to_cents, cents_to_ratio, cents_to_setclass, ratio_to_setclass
-from .utils.intervals import split_interval, harmonic_mean, arithmetic_mean, logarithmic_distance
+from .utils.intervals import split_partial, harmonic_mean, arithmetic_mean, logarithmic_distance
 from .utils.intervals import interval_cost, n_tet, ratios_n_tet
 
 from .utils.frequency_conversion import freq_to_midicents, midicents_to_freq
@@ -72,6 +73,8 @@ __all__ = [
     'AddressedPitchCollection',
     'Scale',
     'Chord',
+    'Sonority',
+    'ChordSequence',
     'Motive',
     'CombinationProductSet',
     'Hexany',
@@ -80,15 +83,17 @@ __all__ = [
     'Eikosany',
     'HarmonicTree',
     'Spectrum',
+    'ToneLattice',
     'AddressedScale',
     'AddressedChord',
+    'AddressedSonority',
     
     # Interval utilities
     'ratio_to_cents',
     'cents_to_ratio',
     'cents_to_setclass',
     'ratio_to_setclass',
-    'split_interval',
+    'split_partial',
     'harmonic_mean',
     'arithmetic_mean',
     'logarithmic_distance',
