@@ -1,6 +1,7 @@
 from .combination_product_sets import CombinationProductSet, Hexany, Dekany, Pentadekany, Eikosany, Hebdomekontany
 from .harmonic_trees import HarmonicTree
 from .harmonic_trees.spectrum import Spectrum
+from .tone_lattices import ToneLattice
 
 __all__ = [
     # Combination product sets
@@ -14,4 +15,7 @@ __all__ = [
     # Harmonic trees
     'HarmonicTree',
     'Spectrum',
+    
+    # Tone lattices
+    'ToneLattice',
 ] 
\ No newline at end of file
